@@ -111,10 +111,12 @@ extern const char *noframes_begin;
 extern const char *noframes_end;
 
 extern const char *tree_control;
+extern const char *tree_loading;
 extern const char *tree_begin;
 extern const char *tree_begin_using;
 extern const char *tree_end;
 extern const char *dir_begin;
+extern const char *dir_title_end;
 extern const char *dir_end;
 extern const char *file_begin;
 extern const char *file_end;
