@@ -395,8 +395,8 @@ parse_file(const char *path, int flags, PARSER_CALLBACK put, void *arg)
 	 * If lang == NULL then default parser is selected.
 	 */
 	ent = get_lang_entry(lang);
-	if (flags & PARSER_DEBUG) {
-		fprintf(stderr, "File '%s' is handled as follows:\n", path);
+	if (flags & PARSER_EXPLAIN) {
+		fprintf(stderr, " File '%s' is handled as follows:\n", path);
 		fprintf(stderr, "\tsuffix:   |%s|\n", suffix);
 		fprintf(stderr, "\tlanguage: |%s|\n", lang);
 		fprintf(stderr, "\tparser:   |%s|\n", ent->parser_name);
